==> icradius-0.10-pre1.tar.gz: icradius-0.10-pre1/scripts/userimport.pl <==
#!/usr/bin/perl -T
########################################################################
#                                                                      #
#    userimport.pl                InnerCite                            #
#                                 Mike Machado <mike@innercite.com>    #
#                                 27 April 1999                        #
#                                                                      #
#    Imports standard RADIUS users file into mysql                     #
#                                                                      #
#                   Copyright under same terms as Cistron RADIUS       #
#                                                                      #
########################################################################


use DBI;
use strict;
my $file = shift || '';

if ($file eq '') {
  print "Usage: userimport.pl users\n";
  exit;
}

my $dbusername = 'root';
my $dbpassword = 'rootpass';
my $dbh = DBI->connect("DBI:mysql:radius", $dbusername, $dbpassword) || die "Cound not connect to radius database as $dbusername\n";

my $lastrow = 0;


open(USER, $file) || die "Cannot open $file for read\n";

my $sth;
my $sql = '';
my ($username, $buffer);
my $lineno = 0;
while (<USER>) {
  $lineno++;
  chop();
  chop();

  next if /^#/;

  if (/^\t/) {
     $lastrow = 0;
     $_ = substr($_, 1, length($_));
     if (substr($_, length($_) -1, 1) eq ',') {
       chop();
     }
     my @avreply = split(/=/);
     $avreply[0] =~ s/^\s+//;
     $avreply[0] =~ s/\s+$//;
     $avreply[1] =~ s/^\s+//;
     $avreply[1] =~ s/\s+$//;
      if ($avreply[0] eq 'Framed-Route') {
        chop($avreply[1]);
        $avreply[1] = substr($avreply[1], 1, length($avreply[1]));
      }

     $sth = $dbh->do("INSERT INTO radreply VALUES \(\'\',\'$username\',\'$avreply[0]\',\'$avreply[1]\'\)");

  } else {
     next if $_ eq '';
     $lastrow = 1 if $_ eq '';
     ($username, $buffer) = split(/\t/);

     my @check = split(/\,/, $buffer);
     foreach (@check) {
       my @avpair = split(/=/);
       $avpair[0] =~ s/^\s+//;
       $avpair[0] =~ s/\s+$//;
       $avpair[1] =~ s/^\s+//;
       $avpair[1] =~ s/\s+$//;
       if ($avpair[0] eq 'Password') {
         chop($avpair[1]);
         $avpair[1] = substr($avpair[1], 1, length($avpair[1]));
       }
       $sth = $dbh->do("INSERT INTO radcheck VALUES \(\'\',\'$username\',\'$avpair[0]\',\'$avpair[1]\'\)");
     }

  }

}

$dbh->disconnect;

==> icradius-0.11.tar.gz: icradius-0.11/scripts/userimport.pl <==
#!/usr/bin/perl -T
########################################################################
#                                                                      #
#    userimport.pl                InnerCite                            #
#                                 Mike Machado <mike@innercite.com>    #
#                                 27 April 1999                        #
#                                                                      #
#    Imports standard RADIUS users file into mysql                     #
#                                                                      #
#                   Copyright under same terms as Cistron RADIUS       #
#                                                                      #
########################################################################


use DBI;
use strict;
my $file = shift || '';

if ($file eq '') {
  print "Usage: userimport.pl users\n";
  exit;
}

my $dbusername = 'root';
my $dbpassword = 'rootpass';
my $dbh = DBI->connect("DBI:mysql:radius", $dbusername, $dbpassword) || die "Cound not connect to radius database as $dbusername\n";

my $lastrow = 0;


open(USER, $file) || die "Cannot open $file for read\n";

my $sth;
my $sql = '';
my ($username, $buffer);
my $lineno = 0;
while (<USER>) {
  $lineno++;
  chop();
  chop();

  next if /^#/;

  if (/^\t/) {
     $lastrow = 0;
     $_ = substr($_, 1, length($_));
     if (substr($_, length($_) -1, 1) eq ',') {
       chop();
     }
     my @avreply = split(/=/);
     $avreply[0] =~ s/^\s+//;
     $avreply[0] =~ s/\s+$//;
     $avreply[1] =~ s/^\s+//;
     $avreply[1] =~ s/\s+$//;
      if (substr($avreply[1], 0, 1) eq '"') {
        chop($avreply[1]);
        $avreply[1] = substr($avreply[1], 1, length($avreply[1]));
      }

     $sth = $dbh->do("INSERT INTO radreply VALUES \(\'\',\'$username\',\'$avreply[0]\',\'$avreply[1]\'\)");

  } else {
     next if $_ eq '';
     $lastrow = 1 if $_ eq '';
     ($username, $buffer) = split(/\t/);

     my @check = split(/\,/, $buffer);
     foreach (@check) {
       my @avpair = split(/=/);
       $avpair[0] =~ s/^\s+//;
       $avpair[0] =~ s/\s+$//;
       $avpair[1] =~ s/^\s+//;
       $avpair[1] =~ s/\s+$//;
       if (substr($avpair[1], 0, 1) eq '"') {
	 # Remove quotes
         chop($avpair[1]);
         $avpair[1] = substr($avpair[1], 1, length($avpair[1]));
       }
       $sth = $dbh->do("INSERT INTO radcheck VALUES \(\'\',\'$username\',\'$avpair[0]\',\'$avpair[1]\'\)");
     }

  }

}

$dbh->disconnect;
